"""
Python module generated from Java source file org.yaml.snakeyaml.util.ArrayStack

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.util import *
from typing import Any, Callable, Iterable, Tuple


class ArrayStack:

    def __init__(self, initSize: int):
        ...


    def push(self, obj: "T") -> None:
        ...


    def pop(self) -> "T":
        ...


    def isEmpty(self) -> bool:
        ...


    def clear(self) -> None:
        ...
