"""
Python module generated from Java source file com.google.common.math.MathPreconditions

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.math import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.math import BigInteger
from java.math import RoundingMode
from typing import Any, Callable, Iterable, Tuple


class MathPreconditions:
    """
    A collection of preconditions for math functions.

    Author(s)
    - Louis Wasserman
    """


