from .LongBinaryOperator import LongBinaryOperator
from .LongUnaryOperator import LongUnaryOperator
from .BooleanSupplier import BooleanSupplier
from .BiFunction import BiFunction
from .BiPredicate import BiPredicate
from .Function import Function
from .Predicate import Predicate
from .Consumer import Consumer
from .BinaryOperator import BinaryOperator
from .Supplier import Supplier
from .UnaryOperator import UnaryOperator
from .BiConsumer import BiConsumer
from .ToIntFunction import ToIntFunction
from .ObjIntConsumer import ObjIntConsumer
from .DoubleConsumer import DoubleConsumer
from .IntConsumer import IntConsumer
from .IntFunction import IntFunction
from .LongConsumer import LongConsumer