"""
Python module generated from Java source file org.bukkit.command.TabExecutor

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class TabExecutor(TabCompleter, CommandExecutor):
    """
    This class is provided as a convenience to implement both TabCompleter and
    CommandExecutor.
    """


